@@ -106,4 +106,10 @@ var (
 	RuntimeConfigFolderPath = DefaultProgramFolder + "runtimeconfig"
 
 	DefaultEC2SharedCredentialsFilePath = DefaultDataStorePath + "credentials"
+
+	// TelemetryDataStorePath specifies the directory where telemetry data is collected before sending
+	TelemetryDataStorePath = DefaultDataStorePath + "telemetry"
+
+	// DynamicConfigFolderPath specifies the directory where dynamicconfig is stored
+	DynamicConfigFolderPath = DefaultDataStorePath + "dynamicconfig"
 )
