@@ -110,6 +110,10 @@ var (
 
 	// DefaultEC2SharedCredentialsFilePath represents the filepath for storing credentials for ec2 identity
 	DefaultEC2SharedCredentialsFilePath = DefaultDataStorePath + "credentials"
+
+	// TelemetryDataStorePath specifies the directory where telemetry data is collected before sending
+	TelemetryDataStorePath  = DefaultDataStorePath + "telemetry"
+	DynamicConfigFolderPath = AgentData + "dynamicconfig"
 )
 
 // PowerShellPluginCommandName is the path of the powershell.exe to be used by the runPowerShellScript plugin
