@@ -76,7 +76,12 @@ func (c *GetInstanceInformationCommand) Execute(subcommands []string, parameters
 		return errors.New(strings.Join(validation, "\n")), ""
 	}
 
-	agentIdentity, err := cliutil.GetAgentIdentity()
+	agentConfig, err := cliutil.GetAgentConfig()
+	if err != nil {
+		return err, ""
+	}
+
+	agentIdentity, err := cliutil.GetAgentIdentity(agentConfig)
 	if err != nil {
 		return err, ""
 	}
