@@ -5,14 +5,14 @@ import (
 
 	"github.com/aws/amazon-ssm-agent/agent/contracts"
 	"github.com/aws/amazon-ssm-agent/agent/mocks/context"
+	"github.com/google/uuid"
 	"github.com/stretchr/testify/assert"
-	"github.com/twinj/uuid"
 )
 
 func TestGetReplyTypeObject_RunCommandResult(t *testing.T) {
 	res := contracts.DocumentResult{ResultType: contracts.RunCommandResult}
 	ctx := context.NewMockDefault()
-	uuid := uuid.NewV4()
+	uuid := uuid.New()
 	replyType, err := GetReplyTypeObject(ctx, res, uuid, 0)
 	expectedReply := NewAgentRunCommandReplyType(ctx, res, uuid, 0)
 	assert.Nil(t, err)
@@ -22,7 +22,7 @@ func TestGetReplyTypeObject_RunCommandResult(t *testing.T) {
 func TestGetReplyType_SessionResult(t *testing.T) {
 	res := contracts.DocumentResult{ResultType: contracts.SessionResult}
 	ctx := context.NewMockDefault()
-	uuid := uuid.NewV4()
+	uuid := uuid.New()
 	replyType, err := GetReplyTypeObject(ctx, res, uuid, 0)
 	expectedReply := NewSessionCompleteType(ctx, res, uuid, 0)
 	assert.Nil(t, err)
@@ -32,7 +32,7 @@ func TestGetReplyType_SessionResult(t *testing.T) {
 func TestGetReplyType_InvalidResultType(t *testing.T) {
 	res := contracts.DocumentResult{ResultType: ""}
 	ctx := context.NewMockDefault()
-	uuid := uuid.NewV4()
+	uuid := uuid.New()
 	_, err := GetReplyTypeObject(ctx, res, uuid, 0)
 	assert.NotNil(t, err)
 }
