@@ -11,19 +11,22 @@
 // either express or implied. See the License for the specific language governing
 // permissions and limitations under the License.
 
+//go:build darwin
 // +build darwin
 
 package network
 
 import (
 	"crypto/x509"
+
+	"github.com/aws/amazon-ssm-agent/agent/appconfig"
 )
 
 func getSystemCertPool() (*x509.CertPool, error) {
 	return x509.SystemCertPool()
 }
 
-func getCustomCertificate() ([]byte, error) {
+func getCustomCertificate(appConfig appconfig.SsmagentConfig) ([]byte, error) {
 	// Custom Certificates not supported on darwin
 	return nil, nil
 }
