@@ -7,6 +7,8 @@ import (
 	"fmt"
 	"testing"
 
+	logger "github.com/aws/amazon-ssm-agent/agent/log"
+	"github.com/aws/amazon-ssm-agent/agent/mocks/log"
 	c "github.com/aws/amazon-ssm-agent/agent/plugins/configurepackage/envdetect/constants"
 	"github.com/stretchr/testify/assert"
 )
@@ -15,15 +17,20 @@ func TestPlatformDetect(t *testing.T) {
 	data := []struct {
 		input    string
 		expected string
+		err      error
 	}{
-		{"10.12.3", "10.12.3"},
-		{"asdf", "asdf"},
-		{"", ""},
+		{"10.12.3", "10.12.3", nil},
+		{"asdf", "asdf", nil},
+		{"", "", nil},
+		{"", "", fmt.Errorf("Error while fetching platform version")},
 	}
+	temp := getPlatformVersion
+	defer func() { getPlatformVersion = temp }()
 	for _, m := range data {
 		t.Run(fmt.Sprintf("%s in %s", m.input, m.expected), func(t *testing.T) {
-			resultVersion := extractDarwinVersion([]byte(m.input))
-			assert.Equal(t, m.expected, string(resultVersion))
+			getPlatformVersion = func(_ logger.T) (string, error) { return m.input, m.err }
+			_, version, _, _ := DetectPlatform(log.NewMockLog())
+			assert.Equal(t, m.expected, version)
 		})
 	}
 }
