@@ -3,6 +3,8 @@ package dockercontainer
 import (
 	"io"
 
+	"github.com/aws/amazon-ssm-agent/agent/context"
+
 	"github.com/aws/amazon-ssm-agent/agent/log"
 	"github.com/aws/amazon-ssm-agent/agent/updateutil"
 )
@@ -11,6 +13,7 @@ var dep dependencies = &deps{}
 
 type dependencies interface {
 	UpdateUtilExeCommandOutput(
+		context context.T,
 		customUpdateExecutionTimeoutInSeconds int,
 		log log.T,
 		cmd string,
@@ -25,6 +28,7 @@ type dependencies interface {
 type deps struct{}
 
 func (deps) UpdateUtilExeCommandOutput(
+	context context.T,
 	customUpdateExecutionTimeoutInSeconds int,
 	log log.T,
 	cmd string,
@@ -34,6 +38,9 @@ func (deps) UpdateUtilExeCommandOutput(
 	stdOut io.Writer,
 	stdErr io.Writer,
 	usePlatformSpecificCommand bool) (output string, err error) {
-	util := updateutil.Utility{CustomUpdateExecutionTimeoutInSeconds: customUpdateExecutionTimeoutInSeconds}
+	util := updateutil.Utility{
+		Context:                               context,
+		CustomUpdateExecutionTimeoutInSeconds: customUpdateExecutionTimeoutInSeconds,
+	}
 	return util.NewExeCommandOutput(log, cmd, parameters, workingDir, outputRoot, stdOut, stdErr, usePlatformSpecificCommand)
 }
