@@ -30,7 +30,7 @@ import (
 	"github.com/aws/amazon-ssm-agent/agent/log"
 	"github.com/aws/amazon-ssm-agent/agent/plugins/inventory/model"
 	"github.com/aws/amazon-ssm-agent/agent/plugins/pluginutil"
-	"github.com/twinj/uuid"
+	"github.com/google/uuid"
 )
 
 var (
@@ -90,7 +90,7 @@ func min(a, b int) int {
 }
 
 func randomString(length int) string {
-	return uuid.NewV4().String()[:length]
+	return uuid.New().String()[:length]
 }
 
 func mark(s string) string {
