@@ -25,6 +25,7 @@ import (
 	"github.com/aws/amazon-ssm-agent/agent/log"
 	"github.com/aws/amazon-ssm-agent/agent/managedInstances/registration"
 	"github.com/aws/amazon-ssm-agent/agent/ssm/authregister"
+	"github.com/aws/amazon-ssm-agent/common/identity/availableidentities/ec2/ec2detector"
 	"github.com/aws/amazon-ssm-agent/common/identity/credentialproviders"
 	"github.com/aws/amazon-ssm-agent/common/identity/credentialproviders/ec2roleprovider"
 	"github.com/aws/amazon-ssm-agent/common/identity/credentialproviders/sharedprovider"
@@ -210,7 +211,6 @@ func (i *Identity) Register(ctx context.Context) error {
 	err = backoffRetry(func() (err error) {
 		return updateServerInfo(instanceId, region, publicKey, privateKey, keyType, IdentityType, registration.EC2RegistrationVaultKey)
 	}, backoffConfig)
-
 	if err != nil {
 		return fmt.Errorf("failed to update EC2 local registration info after successful registration. %w", err)
 	}
@@ -261,6 +261,7 @@ func NewEC2IdentityWithConfig(log log.T, imdsAwsConfig *aws.Config) *Identity {
 		Config:              &config,
 		shareLock:           &sync.RWMutex{},
 		runtimeConfigClient: runtimeconfig.NewIdentityRuntimeConfigClient(),
+		ec2Detector:         ec2detector.New(log),
 	}
 
 	// Ensure IMDS client is initialized before attempting to get instance info
@@ -280,7 +281,7 @@ func NewEC2IdentityWithConfig(log log.T, imdsAwsConfig *aws.Config) *Identity {
 // NewEC2Identity initializes the ec2 identity
 func NewEC2Identity(log log.T) *Identity {
 	awsConfig := &aws.Config{}
-	awsConfig = awsConfig.WithMaxRetries(3).WithEC2MetadataEnableFallback(false)
+	awsConfig = awsConfig.WithMaxRetries(8).WithEC2MetadataEnableFallback(false)
 	return NewEC2IdentityWithConfig(log, awsConfig)
 }
 
