@@ -17,13 +17,12 @@
 package ec2detector
 
 import (
-	"github.com/aws/amazon-ssm-agent/common/identity/availableidentities/ec2/ec2detector/helper"
+	"github.com/aws/amazon-ssm-agent/agent/platform"
 	"github.com/aws/amazon-ssm-agent/common/identity/availableidentities/ec2/ec2detector/nitrodetector"
 	"github.com/aws/amazon-ssm-agent/common/identity/availableidentities/ec2/ec2detector/xendetector"
 )
 
 func init() {
-	detectorHelper := helper.GetDetectorHelper()
-	helper.RegisterDetector(nitrodetector.New(detectorHelper))
-	helper.RegisterDetector(xendetector.New(detectorHelper))
+	RegisterDetector(nitrodetector.New(platform.NitroUuidSystemInfoParamKey, platform.NitroVendorSystemInfoParamKey))
+	RegisterDetector(xendetector.New(platform.XenUuidSystemInfoParamKey, platform.XenVersionSystemInfoParamKey))
 }
