@@ -20,10 +20,13 @@ import (
 	"github.com/aws/amazon-ssm-agent/agent/mocks/log"
 	identityMock "github.com/aws/amazon-ssm-agent/common/identity/mocks"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/mock"
 )
 
 func TestCreateContext(t *testing.T) {
 	logger := log.NewMockLog()
+	logger.On("WithTelemetryNamespace", mock.Anything).Return(logger)
+
 	instanceId := "i-1234567890"
 	ssmAppconfig := &appconfig.SsmagentConfig{}
 
@@ -39,6 +42,8 @@ func TestCreateContext(t *testing.T) {
 
 func TestWithContext(t *testing.T) {
 	logger := &log.Mock{}
+	logger.On("WithTelemetryNamespace", mock.Anything).Return(logger)
+
 	instanceId := "i-1234567890"
 	ssmAppconfig := &appconfig.SsmagentConfig{}
 
@@ -57,3 +62,26 @@ func TestWithContext(t *testing.T) {
 	newContext := context.With("test context")
 	assert.Equal(t, newContext.Log(), loggerNew)
 }
+
+func TestWithTelemetryNamespace(t *testing.T) {
+	logger := &log.Mock{}
+	logger.On("WithTelemetryNamespace", mock.Anything).Return(logger).Once()
+
+	instanceId := "i-1234567890"
+	ssmAppconfig := &appconfig.SsmagentConfig{}
+
+	agentIdentity := &identityMock.IAgentIdentity{}
+	agentIdentity.On("InstanceID").Return(instanceId, nil).Once()
+
+	context, err := NewCoreAgentContext(logger, ssmAppconfig, agentIdentity)
+	assert.Nil(t, err)
+	assert.Equal(t, context.Log(), logger)
+	assert.Equal(t, context.AppConfig(), ssmAppconfig)
+	assert.Equal(t, context.Identity(), agentIdentity)
+
+	loggerNew := &log.Mock{}
+	logger.On("WithTelemetryNamespace", "testNamespace").Return(loggerNew)
+
+	newContext := context.WithTelemetryNamespace("testNamespace")
+	assert.Equal(t, newContext.Log(), loggerNew)
+}
